/** 
 * Dates, with JUnit 3.8. test cases
 *
 * @author Uwe Aßmann
 * The parsing of date strings is a case analysis; many different countries have different
 * date formats, so every country in which the software shall be sold, generates
 * a case (internationalization). In big Enterprise Software frameworks, dates
 * are big classes with a lot of code!
 */

import java.lang.*;  // Integer
import java.lang.reflect.*;  // Method
import java.util.*;
import java.util.zip.DataFormatException;

// JUnit 3.8.X; be careful, it should be listed in the CLASSPATH environment variable
import junit.framework.*;

public class TestGermanDates extends TestCase {
    // Fixture
    DateD date;
    DateD date2;
    DateD date3;
    int result;
    
    public TestGermanDates(String s) { super(s); }

    protected void setUp ()  {
	date = new DateD();
	date2 = new DateD();
	date3 = new DateD();
    }

    /**
     * This example method is full of traps for the execution with the
     * JUnit runner. Please experiment to get it right.
     */
    public void testGerman() {
	System.out.println("Date parsed: Day/Month/Year:"+date.day+":"+date.month+":"+date.year);
	try {
	    // run tests
	    result = date.parseDate("01.10.2013"); 
	    System.out.println("Date parsed: Day/Month/Year:"+date.day+":"+date.month+":"+date.year);
	    assertEquals("1:",date.day,1); // from Assert
	    assertEquals("2:",date.month,10);  
	    assertEquals("3:",date.year,2013);
	    
	    result = date2.parseDate("02. 11. 2014"); 
	    System.out.println("Date parsed: Day/Month/Year:"+date.day+":"+date.month+":"+date.year);
	    assertEquals(date2.day,2);
	    assertEquals(date2.month,11);  
	    assertEquals(date2.year,2014);
	    
	    result = date3.parseDate("12.31.15"); 
	    System.out.println("Date parsed: Day/Month/Year:"+date.day+":"+date.month+":"+date.year);
	    assertEquals("7:",date.day,12);  // bug!
	    assertEquals("8:",date.month,30);  // bug and failure!
	    assertEquals("9:",date.year,2015);  // bug!
	} catch (DataFormatException ex) {
	    System.out.println("TestGermanDates failed on "+ex.toString());
	}
    }
    public void testGerman2() {
	try {
	    // run tests
	    result = date3.parseDate("12.31.2019"); 
	    System.out.println("Date parsed: Day/Month/Year:"+date.day+":"+date.month+":"+date.year);
	} catch (DataFormatException ex) {
	    System.out.println("TestGermanDates failed on "+ex.toString());
	}
    }
    // no tear down necessary
}

